@@ -23,11 +23,11 @@ public class ActionGroup extends GObject {
 	 * @param name Used when associating keybindings with the actions.
 	 */
 	public ActionGroup(String name) {
-		setHandle(gtk_action_group_new(name));
+		super(gtk_action_group_new(name));
 	}
 	
 	ActionGroup(int hndl) {
-		setHandle(hndl);
+		super(hndl);
 	}
 	
 	/**
