@@ -35,7 +35,6 @@ public class TreeModel extends GObject {
 	 */
 	protected TreeModel(int handle) {
 		super(handle);
-		initializeEventHandlers();
 	}
 
 	/*
@@ -132,9 +131,6 @@ public class TreeModel extends GObject {
 		return new TreeIter(hndl, this);
 	}
 
-
-	
-	
 	/***************************************
 	 * Event Handler Related code
 	 ****************************************/
@@ -152,6 +148,11 @@ public class TreeModel extends GObject {
 		int i = findListener(listeners, listener);
 		if (i == -1) {
 			if (null == listeners) {
+				evtMap.initialize(this, TreeModelEvent.Type.ROW_CHANGED);
+				evtMap.initialize(this, TreeModelEvent.Type.ROW_DELETED);
+				evtMap.initialize(this, TreeModelEvent.Type.ROW_HAS_CHILD_TOGGLED);
+				evtMap.initialize(this, TreeModelEvent.Type.ROW_INSERTED);
+				evtMap.initialize(this, TreeModelEvent.Type.ROWS_REORDERED);
 				listeners = new Vector();
 			}
 			listeners.addElement(listener);
@@ -167,6 +168,11 @@ public class TreeModel extends GObject {
 			listeners.remove(i);
 		}
 		if (0 == listeners.size()) {
+			evtMap.uninitialize(this, TreeModelEvent.Type.ROW_CHANGED);
+			evtMap.uninitialize(this, TreeModelEvent.Type.ROW_DELETED);
+			evtMap.uninitialize(this, TreeModelEvent.Type.ROW_HAS_CHILD_TOGGLED);
+			evtMap.uninitialize(this, TreeModelEvent.Type.ROW_INSERTED);
+			evtMap.uninitialize(this, TreeModelEvent.Type.ROWS_REORDERED);
 			listeners = null;
 		}
 	}
@@ -234,14 +240,6 @@ public class TreeModel extends GObject {
 		fireTreeModelEvent(event);
 	}
 
-	protected void initializeEventHandlers() {
-		if (!eventsInitialized) {
-			evtMap.initialize(this);
-			eventsInitialized = true;
-		}
-			
-	}
-
 	public Class getEventListenerClass(String signal) {
 		Class cls = evtMap.getEventListenerClass(signal);
 		if (cls == null) cls = super.getEventListenerClass(signal);
