@@ -20,6 +20,6 @@ public interface ComboBoxListener {
 	 * 
 	 * @param event The event that identifies the details of the event.
 	 */
-	public boolean comboBoxEvent(ComboBoxEvent event);
+	public void comboBoxEvent(ComboBoxEvent event);
 
-}
\ No newline at end of file
+}
